==> haskell-io-streams-1.5.0.1-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams
version: 1.5.0.1
id: io-streams-1.5.0.1-3kE2l2s5RqhB8LMNmX4WMU
key: io-streams-1.5.0.1-3kE2l2s5RqhB8LMNmX4WMU
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: Simple, composable, and easy-to-use stream I/O
description:
    /Overview/
    .
    The io-streams library contains simple and easy-to-use primitives for I/O
    using streams. Most users will want to import the top-level convenience
    module "System.IO.Streams", which re-exports most of the library:
    .
    @
    import           System.IO.Streams (InputStream, OutputStream)
    import qualified System.IO.Streams as Streams
    @
    .
    For first-time users, @io-streams@ comes with an included tutorial, which can
    be found in the "System.IO.Streams.Tutorial" module.
    .
    /Features/
    .
    The @io-streams@ user API has two basic types: @InputStream a@ and
    @OutputStream a@, and three fundamental I/O primitives:
    .
    @
    \-\- read an item from an input stream
    Streams.read :: InputStream a -> IO (Maybe a)
    .
    \-\- push an item back to an input stream
    Streams.unRead :: a -> InputStream a -> IO ()
    .
    \-\- write to an output stream
    Streams.write :: Maybe a -> OutputStream a -> IO ()
    @
    .
    Streams can be transformed by composition and hooked together with provided combinators:
    .
    @
    ghci> Streams.fromList [1,2,3::Int] >>= Streams.map (*10) >>= Streams.toList
    [10,20,30]
    @
    .
    Stream composition leaves the original stream accessible:
    .
    @
    ghci> input \<- Streams.fromByteString \"long string\"
    ghci> wrapped \<- Streams.takeBytes 4 input
    ghci> Streams.read wrapped
    Just \"long\"
    ghci> Streams.read wrapped
    Nothing
    ghci> Streams.read input
    Just \" string\"
    @
    .
    Simple types and operations in the IO monad mean straightforward and simple
    exception handling and resource cleanup using Haskell standard library
    facilities like '\''Control.Exception.bracket'\''.
    .
    @io-streams@ comes with:
    .
    * functions to use files, handles, concurrent channels, sockets, lists,
    vectors, and more as streams.
    .
    * a variety of combinators for wrapping and transforming streams, including
    compression and decompression using zlib, controlling precisely how many
    bytes are read from or written to a stream, buffering output using
    bytestring builders, folds, maps, filters, zips, etc.
    .
    * support for parsing from streams using @attoparsec@.
    .
    * support for spawning processes and communicating with them using streams.
category: Data, Network, IO-Streams
abi: 4aeb39371d7edd673022d6079fe1a91d
exposed: True
exposed-modules:
    System.IO.Streams System.IO.Streams.Attoparsec
    System.IO.Streams.Attoparsec.ByteString
    System.IO.Streams.Attoparsec.Text System.IO.Streams.Builder
    System.IO.Streams.ByteString System.IO.Streams.Combinators
    System.IO.Streams.Concurrent System.IO.Streams.Core
    System.IO.Streams.Debug System.IO.Streams.File
    System.IO.Streams.Handle System.IO.Streams.Internal
    System.IO.Streams.List System.IO.Streams.Network
    System.IO.Streams.Process System.IO.Streams.Text
    System.IO.Streams.Tutorial System.IO.Streams.Vector
    System.IO.Streams.Zlib
hidden-modules: System.IO.Streams.Internal.Attoparsec
                System.IO.Streams.Internal.Network
                System.IO.Streams.Internal.Search
import-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-1.5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/io-streams-1.5.0.1
hs-libraries: HSio-streams-1.5.0.1-3kE2l2s5RqhB8LMNmX4WMU
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq
    bytestring-0.10.8.2 network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc process-1.6.3.0
    text-1.2.3.0 time-1.8.0.2 transformers-0.5.5.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    zlib-bindings-0.1.1.5-CMc0gmEf9KxDLMXiCfo5nN
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq=07053c5359c7530f0cb8534ff020b021
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v=9f1a3e2a2d1ba200f0b4b28f3589f138
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=a76404d2410541ab4c0cf63ee4e3a316
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             zlib-bindings-0.1.1.5-CMc0gmEf9KxDLMXiCfo5nN=440da32352285a56b827fef7b22ba607
haddock-interfaces: /usr/share/doc/haskell-io-streams/html/io-streams.haddock
haddock-html: /usr/share/doc/haskell-io-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-1.5.0.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams
version: 1.5.0.1
id: io-streams-1.5.0.1-GYTv26BuJtI7y8Q4k3saRq
key: io-streams-1.5.0.1-GYTv26BuJtI7y8Q4k3saRq
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: Simple, composable, and easy-to-use stream I/O
description:
    /Overview/
    .
    The io-streams library contains simple and easy-to-use primitives for I/O
    using streams. Most users will want to import the top-level convenience
    module "System.IO.Streams", which re-exports most of the library:
    .
    @
    import           System.IO.Streams (InputStream, OutputStream)
    import qualified System.IO.Streams as Streams
    @
    .
    For first-time users, @io-streams@ comes with an included tutorial, which can
    be found in the "System.IO.Streams.Tutorial" module.
    .
    /Features/
    .
    The @io-streams@ user API has two basic types: @InputStream a@ and
    @OutputStream a@, and three fundamental I/O primitives:
    .
    @
    \-\- read an item from an input stream
    Streams.read :: InputStream a -> IO (Maybe a)
    .
    \-\- push an item back to an input stream
    Streams.unRead :: a -> InputStream a -> IO ()
    .
    \-\- write to an output stream
    Streams.write :: Maybe a -> OutputStream a -> IO ()
    @
    .
    Streams can be transformed by composition and hooked together with provided combinators:
    .
    @
    ghci> Streams.fromList [1,2,3::Int] >>= Streams.map (*10) >>= Streams.toList
    [10,20,30]
    @
    .
    Stream composition leaves the original stream accessible:
    .
    @
    ghci> input \<- Streams.fromByteString \"long string\"
    ghci> wrapped \<- Streams.takeBytes 4 input
    ghci> Streams.read wrapped
    Just \"long\"
    ghci> Streams.read wrapped
    Nothing
    ghci> Streams.read input
    Just \" string\"
    @
    .
    Simple types and operations in the IO monad mean straightforward and simple
    exception handling and resource cleanup using Haskell standard library
    facilities like '\''Control.Exception.bracket'\''.
    .
    @io-streams@ comes with:
    .
    * functions to use files, handles, concurrent channels, sockets, lists,
    vectors, and more as streams.
    .
    * a variety of combinators for wrapping and transforming streams, including
    compression and decompression using zlib, controlling precisely how many
    bytes are read from or written to a stream, buffering output using
    bytestring builders, folds, maps, filters, zips, etc.
    .
    * support for parsing from streams using @attoparsec@.
    .
    * support for spawning processes and communicating with them using streams.
category: Data, Network, IO-Streams
abi: 8fc19154263de72dbf0f48adccedbd46
exposed: True
exposed-modules:
    System.IO.Streams System.IO.Streams.Attoparsec
    System.IO.Streams.Attoparsec.ByteString
    System.IO.Streams.Attoparsec.Text System.IO.Streams.Builder
    System.IO.Streams.ByteString System.IO.Streams.Combinators
    System.IO.Streams.Concurrent System.IO.Streams.Core
    System.IO.Streams.Debug System.IO.Streams.File
    System.IO.Streams.Handle System.IO.Streams.Internal
    System.IO.Streams.List System.IO.Streams.Network
    System.IO.Streams.Process System.IO.Streams.Text
    System.IO.Streams.Tutorial System.IO.Streams.Vector
    System.IO.Streams.Zlib
hidden-modules: System.IO.Streams.Internal.Attoparsec
                System.IO.Streams.Internal.Network
                System.IO.Streams.Internal.Search
import-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-1.5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/io-streams-1.5.0.1
hs-libraries: HSio-streams-1.5.0.1-GYTv26BuJtI7y8Q4k3saRq
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    bytestring-0.10.8.2 network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc process-1.6.3.0
    text-1.2.3.0 time-1.8.0.2 transformers-0.5.5.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    zlib-bindings-0.1.1.5-CMc0gmEf9KxDLMXiCfo5nN
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr=64a54c687aa7806d1b651ff4086a22e3
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=a76404d2410541ab4c0cf63ee4e3a316
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             zlib-bindings-0.1.1.5-CMc0gmEf9KxDLMXiCfo5nN=440da32352285a56b827fef7b22ba607
haddock-interfaces: /usr/share/doc/haskell-io-streams/html/io-streams.haddock
haddock-html: /usr/share/doc/haskell-io-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
